@@ -52,6 +52,19 @@ pub fn parse_cli<'a>() -> clap::ArgMatches<'a> {
         .long("reload-fn")
         .takes_value(true),
     )
+    .arg(
+      clap::Arg::with_name("event-entry")
+        .help("entry ns/def for handling events")
+        .long("event-entry")
+        .default_value("app.main/on-window-event")
+        .takes_value(true),
+    )
+    .arg(
+      clap::Arg::with_name("reload-libs")
+        .help("reload libs data during code reload")
+        .long("reload-libs")
+        .takes_value(false),
+    )
     .arg(
       clap::Arg::with_name("input")
         .help("entry file path, defaults to compact.cirru")
