@@ -160,6 +160,8 @@ fn quote_to_js(xs: &Calcit, var_prefix: &str) -> Result<String, String> {
     Calcit::Bool(b) => Ok(b.to_string()),
     Calcit::Number(n) => Ok(n.to_string()),
     Calcit::Nil => Ok(String::from("null")),
+    // mainly for methods, which are recognized during reading
+    Calcit::Proc(p) => Ok(format!("new {}CrDataSymbol({})", var_prefix, escape_cirru_str(&p))),
     Calcit::List(ys) => {
       let mut chunk = String::from("");
       for y in ys {
@@ -386,8 +388,9 @@ fn gen_call_code(
             }
           }
         }
-        _ if s.starts_with('.') => {
-          let name = s.strip_prefix('.').unwrap();
+        _ if s.starts_with(".!") => {
+          // special syntax for calling a static method, previously using `.` but now occupied
+          let name = s.strip_prefix(".!").unwrap();
           if matches_js_var(name) {
             match body.get(0) {
               Some(obj) => {
@@ -406,6 +409,27 @@ fn gen_call_code(
             Err(format!("invalid member accessor {}", s))
           }
         }
+        _ if s.starts_with('.') => {
+          let name = s.strip_prefix('.').unwrap();
+          if matches_js_var(name) {
+            match body.get(0) {
+              Some(obj) => {
+                let args = body.skip(1);
+                let args_code = gen_args_code(&args, ns, local_defs, file_imports)?;
+                Ok(format!(
+                  "{}invoke_method({},{},{})",
+                  var_prefix,
+                  escape_cirru_str(&name), // TODO need confirm
+                  to_js_code(&obj, ns, local_defs, file_imports)?,
+                  args_code
+                ))
+              }
+              None => Err(format!("expected 1 object, got {}", xs)),
+            }
+          } else {
+            Err(format!("invalid member accessor {}", s))
+          }
+        }
         _ => {
           // TODO
           let args_code = gen_args_code(&body, ns, &local_defs, file_imports)?;
@@ -939,6 +963,7 @@ pub fn emit_js(entry_ns: &str, emit_path: &str) -> Result<(), String> {
 
     let mut defs_code = String::from(""); // code generated by functions
     let mut vals_code = String::from(""); // code generated by thunks
+    let mut direct_code = String::from(""); // dirty code to run directly
 
     let mut import_code = if ns == "calcit.core" {
       snippets::tmpl_import_procs(wrap_js_str("@calcit/procs"))
@@ -1010,6 +1035,11 @@ pub fn emit_js(entry_ns: &str, emit_path: &str) -> Result<(), String> {
           println!("[Warn] strange case for generating a definition: {}", f)
         }
       }
+
+      if ns == primes::CORE_NS {
+        // add at end of file to register builtin classes
+        direct_code.push_str(&snippets::tmpl_classes_registering())
+      }
     }
 
     let collected_imports = file_imports.into_inner();
@@ -1057,7 +1087,10 @@ pub fn emit_js(entry_ns: &str, emit_path: &str) -> Result<(), String> {
     }
 
     let js_file_path = code_emit_path.join(to_js_file_name(&ns, false)); // TODO mjs_mode
-    let wrote_new = write_file_if_changed(&js_file_path, &format!("{}\n{}\n{}", import_code, defs_code, vals_code));
+    let wrote_new = write_file_if_changed(
+      &js_file_path,
+      &format!("{}\n{}\n{}\n{}", import_code, defs_code, vals_code, direct_code),
+    );
     if wrote_new {
       println!("Emitted js file: {}", js_file_path.to_str().unwrap());
     } else {
